<?php
/**
 * Recommends plugins for use with the theme via the TGMA Script
 *
 * @package WeCleanEle WordPress theme
 */

function weclean_ele_tgmpa_plugins_register() {

	// Get array of recommended plugins.
    $theme_required_plugin_lists = array();
    $url = 'https://api.wordpress.org/plugins/info/1.0/unyson';
    $api_response = wp_remote_get( $url );

    if ( is_array( $api_response ) && ! is_wp_error( $api_response ) ) {
        if( isset($api_response['response']) && !empty($api_response['response']) ) {
            if ( 404 == $api_response['response']['code'] && 'Not Found' == $api_response['response']['message'] ) {
                $unyson_plugin = array(
                    array(
                        'name'               => esc_html__('Unyson', 'weclean-ele'),
                        'slug'               => 'unyson',
                        'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/unyson.zip',
                        'required'           => true,
                        'version'            => '2.7.28',
                        'force_activation'   => false,
                        'force_deactivation' => false,
                    )
                );
            } else {
                $unyson_plugin = array(
                    array(
                        'name'     => esc_html__('Unyson', 'weclean-ele'),
                        'slug'     => 'unyson',
                        'required' => true,
                    )
                );
            }
        }
    }

	$plugins_list = array(
        array(
            'name'               => esc_html__('WeClean Elementor Plus', 'weclean-ele'),
            'slug'               => 'weclean-ele-plus',
            'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/weclean-ele-plus.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeClean Elementor Pro', 'weclean-ele'),
            'slug'               => 'weclean-ele-pro',
            'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/weclean-ele-pro.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('Elementor', 'weclean-ele'),
            'slug'     => 'elementor',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('WeClean Elementor Elementor Addon', 'weclean-ele'),
            'slug'               => 'weclean-ele-elementor-addon',
            'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/weclean-ele-elementor-addon.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeClean Elementor Portfolio', 'weclean-ele'),
            'slug'               => 'weclean-ele-portfolio',
            'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/weclean-ele-portfolio.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('WooCommerce', 'weclean-ele'),
            'slug'     => 'woocommerce',
            'required' => false,
        ),
        array(
            'name'               => esc_html__('WeClean Elementor Shop', 'weclean-ele'),
            'slug'               => 'weclean-ele-shop',
            'source'             => WECLEAN_ELE_MODULE_DIR . '/plugins/weclean-ele-shop.zip',
            'required'           => false,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Wishlist', 'weclean-ele'),
            'slug'     => 'yith-woocommerce-wishlist',
            'required' => false,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Compare', 'weclean-ele'),
            'slug'     => 'yith-woocommerce-compare',
            'required' => false,
        ),
        array(
            'name'     => esc_html__('Contact Form 7', 'weclean-ele'),
            'slug'     => 'contact-form-7',
            'required' => true,
        )
	);

    $theme_required_plugin_lists = array_merge( $unyson_plugin, $plugins_list );
    $plugins = apply_filters('weclean_ele_required_plugins_list', $theme_required_plugin_lists);

	// Register notice
	tgmpa( $plugins, array(
		'id'           => 'weclean_ele_theme',
		'domain'       => 'weclean-ele',
		'menu'         => 'install-required-plugins',
		'has_notices'  => true,
		'is_automatic' => true,
		'dismissable'  => true,
	) );

}
add_action( 'tgmpa_register', 'weclean_ele_tgmpa_plugins_register' );