<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if( !class_exists( 'WeCleanEle_Shop_Metabox_Single_Upsell_Related' ) ) {
    class WeCleanEle_Shop_Metabox_Single_Upsell_Related {

        private static $_instance = null;

        public static function instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        function __construct() {

			add_filter( 'weclean_ele_shop_product_custom_settings', array( $this, 'weclean_ele_shop_product_custom_settings' ), 10 );

		}

        function weclean_ele_shop_product_custom_settings( $options ) {

			$ct_dependency      = array ();
			$upsell_dependency  = array ( 'show-upsell', '==', 'true');
			$related_dependency = array ( 'show-related', '==', 'true');
			if( function_exists('weclean_ele_shop_single_module_custom_template') ) {
				$ct_dependency['dependency'] 	= array ( 'product-template', '!=', 'custom-template');
				$upsell_dependency 				= array ( 'product-template|show-upsell', '!=|==', 'custom-template|true');
				$related_dependency 			= array ( 'product-template|show-related', '!=|==', 'custom-template|true');
			}

			$product_options = array (

				array_merge (
					array(
						'id'         => 'show-upsell',
						'type'       => 'select',
						'title'      => esc_html__('Show Upsell Products', 'weclean-ele'),
						'class'      => 'chosen',
						'default'    => 'admin-option',
						'attributes' => array( 'data-depend-id' => 'show-upsell' ),
						'options'    => array(
							'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
							'true'         => esc_html__( 'Show', 'weclean-ele'),
							null           => esc_html__( 'Hide', 'weclean-ele'),
						)
					),
					$ct_dependency
				),

				array(
					'id'         => 'upsell-column',
					'type'       => 'select',
					'title'      => esc_html__('Choose Upsell Column', 'weclean-ele'),
					'class'      => 'chosen',
					'default'    => 4,
					'options'    => array(
						'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
						1              => esc_html__( 'One Column', 'weclean-ele' ),
						2              => esc_html__( 'Two Columns', 'weclean-ele' ),
						3              => esc_html__( 'Three Columns', 'weclean-ele' ),
						4              => esc_html__( 'Four Columns', 'weclean-ele' ),
					),
					'dependency' => $upsell_dependency
				),

				array(
					'id'         => 'upsell-limit',
					'type'       => 'select',
					'title'      => esc_html__('Choose Upsell Limit', 'weclean-ele'),
					'class'      => 'chosen',
					'default'    => 4,
					'options'    => array(
						'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
						1              => esc_html__( 'One', 'weclean-ele' ),
						2              => esc_html__( 'Two', 'weclean-ele' ),
						3              => esc_html__( 'Three', 'weclean-ele' ),
						4              => esc_html__( 'Four', 'weclean-ele' ),
						5              => esc_html__( 'Five', 'weclean-ele' ),
						6              => esc_html__( 'Six', 'weclean-ele' ),
						7              => esc_html__( 'Seven', 'weclean-ele' ),
						8              => esc_html__( 'Eight', 'weclean-ele' ),
						9              => esc_html__( 'Nine', 'weclean-ele' ),
						10              => esc_html__( 'Ten', 'weclean-ele' ),
					),
					'dependency' => $upsell_dependency
				),

				array_merge (
					array(
						'id'         => 'show-related',
						'type'       => 'select',
						'title'      => esc_html__('Show Related Products', 'weclean-ele'),
						'class'      => 'chosen',
						'default'    => 'admin-option',
						'attributes' => array( 'data-depend-id' => 'show-related' ),
						'options'    => array(
							'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
							'true'         => esc_html__( 'Show', 'weclean-ele'),
							null           => esc_html__( 'Hide', 'weclean-ele'),
						)
					),
					$ct_dependency
				),

				array(
					'id'         => 'related-column',
					'type'       => 'select',
					'title'      => esc_html__('Choose Related Column', 'weclean-ele'),
					'class'      => 'chosen',
					'default'    => 4,
					'options'    => array(
						'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
						2              => esc_html__( 'Two Columns', 'weclean-ele' ),
						3              => esc_html__( 'Three Columns', 'weclean-ele' ),
						4              => esc_html__( 'Four Columns', 'weclean-ele' ),
					),
					'dependency' => $related_dependency
				),

				array(
					'id'         => 'related-limit',
					'type'       => 'select',
					'title'      => esc_html__('Choose Related Limit', 'weclean-ele'),
					'class'      => 'chosen',
					'default'    => 4,
					'options'    => array(
						'admin-option' => esc_html__( 'Admin Option', 'weclean-ele' ),
						1              => esc_html__( 'One', 'weclean-ele' ),
						2              => esc_html__( 'Two', 'weclean-ele' ),
						3              => esc_html__( 'Three', 'weclean-ele' ),
						4              => esc_html__( 'Four', 'weclean-ele' ),
						5              => esc_html__( 'Five', 'weclean-ele' ),
						6              => esc_html__( 'Six', 'weclean-ele' ),
						7              => esc_html__( 'Seven', 'weclean-ele' ),
						8              => esc_html__( 'Eight', 'weclean-ele' ),
						9              => esc_html__( 'Nine', 'weclean-ele' ),
						10              => esc_html__( 'Ten', 'weclean-ele' ),
					),
					'dependency' => $related_dependency
				)

			);

			$options = array_merge( $options, $product_options );

			return $options;

		}

    }
}

WeCleanEle_Shop_Metabox_Single_Upsell_Related::instance();